@@ -385,7 +385,7 @@ DisplayCountNotSmoked (sotsuval sv)
     gchar tmsg[50];
   } tablelen;
 
-  tablelen TableLen[] = {
+tablelen TableLen[] = {
     {800000.00, "成層圏を脱しました！"},
     {565400.00, "国道１号線"},
     {500000.00, "アマゾン川河口幅"},
@@ -412,14 +412,17 @@ DisplayCountNotSmoked (sotsuval sv)
     {6194.00, "北アメリカ最高峰"},
     {5895.00, "アフリカ最高峰"},
     {5156.00, "アララト山"},
+    {5000.00, "ディズニーモノレール１周"},
     {4897.00, "南極最高峰"},
     {4807.00, "ヨーロッパ最高峰"},
+    {4800.00, "平城京の南北幅"},
     {4424.00, "エベレスト５合目"},
     {4295.00, "ハワイ最高峰"},
     {4000.00, "成田空港Ａ滑走路"},
     {3975.00, "アイガー"},
     {3927.00, "１里"},
     {3911.00, "明石海峡大橋全長"},
+    {3800.00, "イグアスの滝（全幅）"},
     {3776.00, "富士山"},
     {3750.00, "関西国際空港連絡橋"},
     {3614.00, "関門鉄道トンネル下り"},
@@ -438,6 +441,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {2530.00, "諏訪富士"},
     {2486.00, "男体山"},
     {2479.00, "スチールドラゴンの全長"},
+    {2450.00, "立山室堂平標高"},
     {2380.00, "日本坂トンネル旧左"},
     {2370.00, "日本坂トンネル旧右"},
     {2300.00, "地獄谷温泉標高"},
@@ -447,6 +451,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {2228.00, "オーストラリア最高峰"},
     {2191.00, "恵那山"},
     {2077.00, "十勝岳"},
+    {2038.00, "岩手山"},
     {1982.00, "石鎚山天狗岳"},
     {1970.00, "ゴールデンゲート橋"},
     {1936.00, "屋久島"},
@@ -469,6 +474,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {1629.00, "大鳴門橋"},
     {1620.00, "バイカル湖最大深度"},
     {1609.34, "１マイル"},
+    {1600.00, "ワイキキビーチ"},
     {1592.00, "阿蘇山"},
     {1584.00, "八甲田山"},
     {1523.00, "新富士川大橋"},
@@ -485,17 +491,21 @@ DisplayCountNotSmoked (sotsuval sv)
     {1413.00, "石狩河口大橋"},
     {1405.00, "ペンタゴンの全周"},
     {1400.00, "尾瀬ヶ原"},
+    {1378.00, "雄阿寒岳"},
     {1377.00, "伊吹山"},
     {1359.00, "雲仙普賢岳"},
     {1346.00, "野辺山駅海抜"},
     {1332.00, "東京タワー４本"},
     {1300.00, "野辺山高原"},
     {1269.00, "中禅寺湖の標高"},
+    {1230.00, "瓢湖の全周"},
     {1219.00, "世界最長の滑り台"},
     {1200.00, "草津温泉標高"},
+    {1192.00, "大滝根山"},
     {1190.00, "六本木ヒルズ５本"},
     {1189.00, "ドドンパの全長"},
     {1170.00, "名港中央大橋"},
+    {1142.00, "ブロッケン山"},
     {1132.80, "富士山３合目"},
     {1124.80, "サンダードルフィンの全長"},
     {1117.00, "桜島"},
@@ -513,6 +523,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {931.10, "六甲山"},
     {930.00, "黒部ダム５個"},
     {924.00, "開聞岳"},
+    {900.00, "ナイアガラ・カナダ滝の幅"},
     {897.40, "蓬莱橋"},
     {890.00, "多々羅大橋"},
     {884.80, "エベレスト１合目"},
@@ -561,6 +572,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {510.00, "シンデレラ城１０城"},
     {509.00, "台北１０１"},
     {503.00, "与那覇岳"},
+    {500.00, "阿武隈高地平均標高"},
     {492.86, "ドラコン世界記録"},
     {490.00, "生口橋"},
     {486.00, "仁徳天皇陵"},
@@ -571,6 +583,8 @@ DisplayCountNotSmoked (sotsuval sv)
     {458.45, "ヤーレ・バイキング号"},
     {455.00, "対馬オメガ局電波標識塔"},
     {452.00, "ペトロナスツインタワー"},
+    {450.00, "京都御所南北幅"},
+    {445.00, "金華山"},
     {442.00, "シアーズタワー"},
     {438.00, "クフ王のピラミッド３個"},
     {426.00, "ジブラルタロック"},
@@ -590,9 +604,11 @@ DisplayCountNotSmoked (sotsuval sv)
     {365.00, "ベルリンテレビ塔"},
     {360.00, "百舌鳥陵山"},
     {350.00, "エアーズロック"},
+    {349.00, "称名滝"},
     {348.00, "高雄タワー"},
     {343.00, "音が１秒間に進む距離"},
-    {342.00, "奈良の若草山"},
+    {342.50, "奈良の若草山"},
+    {342.00, "青の洞門（大分）"},
     {335.00, "東京駅丸の内駅舎"},
     {333.00, "東京タワー"},
     {330.00, "横須賀基地のドック"},
@@ -605,6 +621,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {310.59, "余部橋梁"},
     {310.00, "アゼリーテレビタワー"},
     {305.00, "新木津川大橋"},
+    {304.00, "ナイアガラ・アメリカ滝の幅"},
     {300.00, "鶴の舞橋"},
     {298.00, "明石海峡大橋主塔"},
     {297.00, "大三島橋"},
@@ -628,6 +645,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {255.00, "シンデレラ城５城"},
     {254.00, "新浜寺大橋"},
     {252.00, "大阪ＷＴＣ"},
+    {251.00, "京都御所東西幅"},
     {250.00, "東京タワー特別展望台"},
     {248.00, "東京ミッドタウン"},
     {247.00, "ミッドランドスクエア"},
@@ -651,10 +669,12 @@ DisplayCountNotSmoked (sotsuval sv)
     {199.20, "聖路加国際病院タワー"},
     {199.00, "畝傍山"},
     {195.00, "スカイタワー西東京"},
+    {193.50, "錦帯橋"},
     {193.00, "日本テレビタワー"},
     {192.00, "ゲートウェイアーチ"},
     {189.00, "国道１７４号線全長"},
     {186.00, "黒部ダム"},
+    {185.00, "スキーフライングヒル"},
     {182.00, "オーク１番街ビル"},
     {180.00, "名古屋テレビ塔"},
     {178.00, "サグラダ・ファミリア（未完）"},
@@ -673,6 +693,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {155.00, "渡月橋全長"},
     {153.00, "海峡ゆめタワー"},
     {152.00, "天香具山"},
+    {151.00, "モンサンミッシェル"},
     {150.00, "東京タワー展望台"},
     {149.80, "奈良の大仏１０体"},
     {147.20, "札幌テレビ塔"},
@@ -710,9 +731,12 @@ DisplayCountNotSmoked (sotsuval sv)
     {103.00, "通天閣"},
     {102.00, "博多ポートタワー"},
     {100.00, "キングギドラ昭和"},
+    {99.80, "石廊崎の断崖高"},
     {99.40, "シーウルフ級原潜"},
     {98.48, "槍投げ世界記録"},
+    {98.00, "ナイアガラの滝・最大落差"},
     {97.00, "自由の女神"},
+    {96.50, "華厳の滝"},
     {95.00, "ビッグベン"},
     {93.50, "スチールドラゴンの落差"},
     {91.00, "バベルの塔（推定）"},
@@ -726,6 +750,8 @@ DisplayCountNotSmoked (sotsuval sv)
     {84.00, "ヤフードーム"},
     {83.20, "ルイジアナ・スーパードーム"},
     {83.09, "大阪ドーム"},
+    {82.00, "足摺岬の断崖高"},
+    {81.00, "イグアスの滝"},
     {80.00, "デーモン小暮閣下"},
     {79.42, "東京ドームのビッグ・オー"},
     {79.00, "オシンコシンの滝"},
@@ -735,6 +761,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {74.08, "円盤投げ世界記録"},
     {71.00, "楽山大仏"},
     {70.00, "太陽の塔"},
+    {69.50, "ゴールデンゲート橋の高さ"},
     {68.00, "ガラタ塔"},
     {67.50, "世界一大きなドア"},
     {67.00, "オペラハウス"},
@@ -752,30 +779,39 @@ DisplayCountNotSmoked (sotsuval sv)
     {54.80, "東寺五重塔"},
     {54.00, "川崎マリエン"},
     {53.80, "なんだろう橋"},
+    {53.40, "カプリ島 青の洞窟（奥行）"},
     {53.00, "Ｈ２Ａロケット"},
     {52.00, "ナイアガラの滝"},
     {51.00, "シンデレラ城"},
     {50.00, "パリ凱旋門"},
+    {49.70, "石舞台古墳の一辺"},
     {49.30, "日本最高のはしご車"},
     {49.00, "東大寺大仏殿"},
     {48.00, "出雲ドーム"},
+    {47.50, "藤ノ木古墳の直径"},
     {47.00, "いよてつ高島屋くるりん"},
     {46.35, "姫路城天守閣"},
     {45.00, "ウルトラの父"},
     {43.70, "日御碕灯台"},
     {43.00, "太陽の船"},
+    {42.70, "稚内灯台"},
     {41.80, "高崎白衣大観音"},
+    {41.60, "摩周湖の最高透明度"},
     {41.20, "余部鉄橋の高さ"},
     {40.00, "ウルトラマン"},
+    {39.00, "東京湾の最大深度"},
     {38.00, "スペースマウンテン"},
     {37.00, "スペースシャトル"},
     {36.60, "ライト兄弟初飛行距離"},
     {36.50, "世界最大のクラゲ"},
     {36.00, "東照宮五重塔"},
+    {35.70, "綱引きの綱"},
     {35.40, "百尺観音（現状）"},
     {35.00, "薬師寺の西塔"},
+    {34.70, "ボロブドゥール"},
     {34.10, "ピーナッツ投げ世界記録"},
     {33.60, "薬師寺の東塔"},
+    {32.80, "立った奈良の大仏（推定）"},
     {32.00, "ウシュマル遺跡ピラミッド"},
     {31.40, "ポロブドゥール寺院"},
     {31.20, "瑠璃光寺五重塔"},
@@ -787,6 +823,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {27.43, "野球の塁間距離"},
     {27.35, "新幹線先頭車両"},
     {27.00, "ストーンマウンテンの彫刻"},
+    {26.50, "千石船"},
     {26.00, "ディプロドクス"},
     {25.30, "縄文杉"},
     {25.10, "高野山大門"},
@@ -796,14 +833,17 @@ DisplayCountNotSmoked (sotsuval sv)
     {24.00, "立った鎌倉大仏（推定）"},
     {23.82, "フォックスバットＢ"},
     {23.77, "テニスコート"},
+    {23.72, "ボーリングのレーン"},
     {23.12, "砲丸投げ世界記録"},
     {22.50, "ナガスクジラ"},
     {22.00, "平城宮跡朱雀門"},
     {21.48, "蒸気機関車Ｃ６２炭水車付"},
     {21.10, "ＺＺガンダム"},
     {21.00, "ルーブル美術館のピラミッド"},
+    {20.70, "モアイ像（最大）"},
     {20.00, "道頓堀グリコのネオン"},
     {19.80, "ダイオウイカ"},
+    {19.50, "石舞台古墳の石室全長"},
     {19.00, "フルトレーラー"},
     {18.70, "Ｚガンダム"},
     {18.44, "ピッチャーとホーム間距離"},
@@ -813,6 +853,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {17.50, "ガンキャノン(RX-77)"},
     {17.00, "シャア専用ザク"},
     {16.00, "諏訪大社の御柱"},
+    {15.80, "杏の木（野生）"},
     {14.98, "奈良の大仏"},
     {14.68, "坂本龍馬像台座有"},
     {14.50, "アナコンダ"},
@@ -821,17 +862,21 @@ DisplayCountNotSmoked (sotsuval sv)
     {13.30, "ティラノサウルス"},
     {13.00, "出雲大社注連縄"},
     {12.50, "金閣寺"},
+    {12.25, "カプリ島 青の洞窟（高さ）"},
     {12.00, "竿灯（大人用標準）"},
     {11.37, "妖怪一反木綿"},
     {11.35, "鎌倉の大仏"},
     {11.10, "東照宮陽明門"},
     {10.60, "ジンベイザメ"},
+    {10.40, "豊浜祭り 鯛の張り子"},
     {10.20, "鉄人２８号"},
     {10.00, "蒸気機関車Ｄ５１"},
     {9.93, "土渕海峡"},
     {9.70, "長崎平和祈念像"},
+    {9.50, "イグアノドン"},
     {8.95, "走り幅跳び世界記録"},
     {8.88, "大山カラス天狗像"},
+    {8.65, "トリケラトプス"},
     {8.42, "金剛力士立像吽形"},
     {8.36, "金剛力士立像阿形"},
     {8.20, "すばる望遠鏡の口径"},
@@ -844,6 +889,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {6.37, "アポロ月着陸船"},
     {6.25, "アミメニシキヘビ"},
     {6.14, "棒高跳び世界記録"},
+    {6.08, "イッカク"},
     {6.00, "尾長鶏の尻尾"},
     {5.90, "クロコダイル"},
     {5.80, "キリンのジョージ"},
@@ -859,20 +905,30 @@ DisplayCountNotSmoked (sotsuval sv)
     {4.00, "ティラノサウルス"},
     {3.96, "アフリカゾウ"},
     {3.71, "西郷隆盛像上野"},
+    {3.66, "カーリングハウス直径"},
+    {3.50, "マンモスの体高"},
     {3.42, "高枝切り鋏"},
     {3.40, "軽自動車の全長"},
     {3.27, "知恩院の鐘"},
+    {3.12, "十三湖の最大水深"},
+    {3.06, "バンドウイルカ"},
+    {3.03, "アフリカ象の牙"},
     {3.00, "ラグビークロスバー"},
+    {2.95, "マカジキ"},
     {2.85, "アカカンガルー♂全長"},
+    {2.80, "アラスカヒグマ"},
     {2.75, "キタアフリカダチョウ"},
     {2.72, "人間の身長世界記録"},
     {2.45, "走り高跳び世界記録"},
     {2.43, "バレーボールのネット"},
+    {2.40, "ハッブル宇宙望遠鏡の口径"},
+    {2.35, "ホッキョクグマ"},
     {2.25, "コモドオオトカゲ♂"},
     {2.14, "ミロのビーナス"},
     {2.10, "ラクダ"},
     {2.09, "ジャイアント馬場"},
     {2.02, "曙　太郎"},
+    {2.00, "アホウドリの翼長"},
     {1.95, "仮面ライダー"},
     {1.93, "リンカーン大統領"},
     {1.90, "男子立ち高飛び世界記録"},
@@ -883,8 +939,10 @@ DisplayCountNotSmoked (sotsuval sv)
     {1.65, "ペガサス星矢"},
     {1.55, "郵便差出箱１号土台付き"},
     {1.52, "女子立ち高飛び世界記録"},
+    {1.50, "ブリ"},
     {1.46, "Ｂ０版の長辺"},
     {1.44, "新幹線のレール幅"},
+    {1.40, "しゃこがい"},
     {1.35, "郵便差出箱１号"},
     {1.29, "ドラえもん"},
     {1.20, "平均台の高さ"},
@@ -897,7 +955,7 @@ DisplayCountNotSmoked (sotsuval sv)
     {0.18, "鉛筆"},
     {0.11, "ダチョウの卵"},
     {0.00, "ガンバレ－"},
-  };
+};
 
   honsu = sv.CCount;
   nagasa = sv.CLen;
